@@ -30,9 +30,14 @@ class TicketAPI(object):
     def __init__(self, api):
         self._api = api
 
-    def get_ticket(self, ticket_id):
-        """Fetches the ticket for the given ticket ID"""
-        url = "tickets/%d" % ticket_id
+    def get_ticket(self, ticket_id, *include):
+        """
+            Fetches the ticket for the given ticket ID
+            You can pass strings for the include parameter and they'll be included as include params to the request
+            ex: get_ticket(some_id, "stats", "conversations", "requester", "company") will result in the following request:
+            tickets/[some_id]?include=stats,conversations,requester,company
+        """
+        url = "tickets/%d%s" % (ticket_id, "?include=%s" % ",".join(include) if include else "")
         ticket = self._api._get(url)
         return Ticket(**ticket)
 
@@ -135,9 +140,13 @@ class TicketAPI(object):
             url += "?filter=%s&" % filter_name
         else:
             url += "?"
+
+        if "updated_since" in kwargs:
+            url += "updated_since=%s&" % kwargs["updated_since"]
+
         page = kwargs.get("page", 1)
         per_page = kwargs.get("per_page", 100)
-
+        
         tickets = []
 
         # Skip pagination by looping over each page and adding tickets if 'page' key is not in kwargs.
@@ -394,6 +403,11 @@ class CompanyAPI(object):
             page += 1
 
         return [Company(**c) for c in companies]
+    
+    def delete_company(self, company_id):
+        """Delete the company for the given company ID"""
+        url = "companies/%d" % company_id
+        self._api._delete(url)
 
 
 class RoleAPI(object):
